@@ -25,24 +25,6 @@ SELINUX_TAG=$(ls -Z)
 
 mkdir -p /images/datavolume1 /images/datavolume2 /images/datavolume3
 
-echo "converting cirros image from qcow2 to raw, and copying it to local-storage directory, and creating a loopback device from it"
-# /local-storage will be mapped to the host dir, which will also be used by the local storage provider
-qemu-img convert -f qcow2 -O raw /images/cirros/disk.img /local-storage/cirros.img.raw
-
-# Check if attached loopdevice reach limit number (100)
-num=$(losetup -l | wc -l)
-[ ${num} -gt 100 ] && echo "attached loopdevices have reach limit number(100)" && exit 1
-
-# Put LOOP_DEVICE in /etc/bashrc in order to detach this loop device when the pod stopped.
-LOOP_DEVICE=$(losetup --find --show /local-storage/cirros.img.raw)
-echo LOOP_DEVICE=${LOOP_DEVICE} >>/etc/bashrc
-rm -f /local-storage/cirros-block-device
-ln -s $LOOP_DEVICE /local-storage/cirros-block-device
-
-echo "converting fedora image from qcow2 to raw"
-qemu-img convert -f qcow2 -O raw /images/fedora-cloud/disk.qcow2 /images/fedora-cloud/disk.img
-rm /images/fedora-cloud/disk.qcow2
-
 echo "copy all images to host mount directory"
 cp -R /images/* /hostImages/
 echo "make the alpine image ready for parallel use"
@@ -50,6 +32,10 @@ cp -r /hostImages/alpine hostImages/alpine1
 cp -r /hostImages/alpine hostImages/alpine2
 cp -r /hostImages/alpine hostImages/alpine3
 rm -rf /hostImages/alpine
+mkdir -p /local-storage/hotplug-test
+cp -r /hostImages/custom/disk.img /local-storage/hotplug-test/disk.img
+chmod -R 777 /local-storage/hotplug-test
+
 echo "make the custom image ready for parallel use"
 cp -r /hostImages/custom hostImages/custom1
 cp -r /hostImages/custom hostImages/custom2
@@ -63,6 +49,27 @@ if [ ${SELINUX_TAG:0:1} != "?" ]; then
     chcon -Rt svirt_sandbox_file_t /hostImages
 fi
 
+# Create a 4Gi blank disk image
+dd if=/dev/zero of=/local-storage/hp_file.img bs=4k count=1024k
+ls -al /local-storage/hp_file.img
+# Put LOOP_DEVICE_HP in /etc/bashrc in order to detach this loop device when the pod stopped.
+LOOP_DEVICE_HP=$(chroot /host losetup --verbose --find --show /mnt/local-storage/hp_file.img)
+echo LOOP_DEVICE_HP=${LOOP_DEVICE_HP} >>/etc/bashrc
+chroot /host mkfs.ext4 $LOOP_DEVICE_HP
+mkdir -p /hostImages/mount_hp
+ls -al /host${LOOP_DEVICE_HP}
+chroot /host mount ${LOOP_DEVICE_HP} /tmp/hostImages/mount_hp
+mkdir -p /host/tmp/hostImages/mount_hp/test
+# When the host is ubuntu, by default, selinux is not used, so chcon is not necessary.
+# If selinux tag is set, use chcon to change /hostImages privileges.
+if [ ${SELINUX_TAG:0:1} != "?" ]; then
+    chcon -Rt svirt_sandbox_file_t /host/tmp/hostImages/mount_hp
+fi
+chmod 777 /host/tmp/hostImages/mount_hp
+chmod 777 /host/tmp/hostImages/mount_hp/test
+
+cat /etc/bashrc
+
 # for some reason without sleep, container sometime fails to create the file
 sleep 10
 
